@@ -38,7 +38,6 @@
 #include <KCharsets>
 #include <KCodecs>
 
-#include <QTextCodec>
 
 #include <assert.h>
 #include <ctype.h>
@@ -364,7 +363,8 @@ QVector<QByteArray> MailboxList::addresses() const
 {
     QVector<QByteArray> rv;
     rv.reserve(d_func()->mailboxList.count());
-    foreach (const Types::Mailbox &mbox, d_func()->mailboxList) {
+    const auto mailboxList = d_func()->mailboxList;
+    for (const Types::Mailbox &mbox : mailboxList) {
         rv.append(mbox.address());
     }
     return rv;
@@ -424,11 +424,7 @@ bool MailboxList::parse(const char *&scursor, const char *const send,
         if (!(it).displayName.isEmpty()) {
             KMIME_WARN << "mailbox groups in header disallowing them! Name: \""
                        << (it).displayName << "\""
-              #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
-                       << endl
-              #else
                        << Qt::endl
-              #endif
                           ;
         }
         d->mailboxList += (it).mailboxList;
@@ -454,12 +450,7 @@ bool SingleMailbox::parse(const char *&scursor, const char *const send,
 
     if (d->mailboxList.count() > 1) {
         KMIME_WARN << "multiple mailboxes in header allowing only a single one!"
-              #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
-                   << endl
-              #else
-                   << Qt::endl
-              #endif
-                      ;
+                   << Qt::endl;
     }
     return true;
 }
@@ -508,7 +499,8 @@ QString AddressList::asUnicodeString() const
     QStringList rv;
     for (const Types::Address &addr : qAsConst(d->addressList)) {
         rv.reserve(rv.size() + addr.mailboxList.size());
-        foreach (const Types::Mailbox &mbox, addr.mailboxList) {
+        const auto mailboxList = addr.mailboxList;
+        for (const Types::Mailbox &mbox : mailboxList) {
             rv.append(mbox.prettyAddress());
         }
     }
@@ -549,8 +541,10 @@ void AddressList::addAddress(const QByteArray &address,
 QVector<QByteArray> AddressList::addresses() const
 {
     QVector<QByteArray> rv;
-    foreach (const Types::Address &addr, d_func()->addressList) {
-        foreach (const Types::Mailbox &mbox, addr.mailboxList) {
+    const auto addressList = d_func()->addressList;
+    for (const Types::Address &addr : addressList) {
+        const auto mailboxList = addr.mailboxList;
+        for (const Types::Mailbox &mbox : mailboxList) {
             rv.append(mbox.address());
         }
     }
@@ -582,8 +576,10 @@ QString AddressList::displayString() const
 Types::Mailbox::List AddressList::mailboxes() const
 {
     Types::Mailbox::List rv;
-    foreach (const Types::Address &addr, d_func()->addressList) {
-        foreach (const Types::Mailbox &mbox, addr.mailboxList) {
+    const auto addressList = d_func()->addressList;
+    for (const Types::Address &addr : addressList) {
+        const auto mailboxList = addr.mailboxList;
+        for (const Types::Mailbox &mbox : mailboxList) {
             rv.append(mbox);
         }
     }
@@ -666,12 +662,7 @@ bool Token::parse(const char *&scursor, const char *const send, bool isCRLF)
     if (scursor != send) {
         KMIME_WARN << "trailing garbage after token in header allowing "
                    "only a single token!"
-              #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
-                   << endl
-              #else
-                   << Qt::endl
-              #endif
-                      ;
+                   << Qt::endl;
     }
     return true;
 }
@@ -819,12 +810,7 @@ bool DotAtom::parse(const char *&scursor, const char *const send,
     if (scursor != send) {
         KMIME_WARN << "trailing garbage after dot-atom in header allowing "
                    "only a single dot-atom!"
-              #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
-                   << endl
-              #else
-                   << Qt::endl
-              #endif
-                      ;
+                   << Qt::endl;
     }
     return true;
 }
@@ -1013,7 +999,8 @@ bool Ident::parse(const char *&scursor, const char *const send, bool isCRLF)
 QVector<QByteArray> Ident::identifiers() const
 {
     QVector<QByteArray> rv;
-    foreach (const Types::AddrSpec &addr, d_func()->msgIdList) {
+    const auto msgIdList = d_func()->msgIdList;
+    for (const Types::AddrSpec &addr : msgIdList) {
         if (!addr.isEmpty()) {
             const QString asString = addr.asString();
             if (!asString.isEmpty()) {
@@ -1097,12 +1084,7 @@ bool SingleIdent::parse(const char *&scursor, const char *const send,
     if (d->msgIdList.count() > 1) {
         KMIME_WARN << "more than one msg-id in header "
                    << "allowing only a single one!"
-              #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
-                   << endl
-              #else
-                   << Qt::endl
-              #endif
-                      ;
+                   << Qt::endl;
     }
     return true;
 }
@@ -1177,13 +1159,7 @@ bool ReturnPath::parse(const char *&scursor, const char *const send,
         // check that there was no display-name:
         if (maybeMailbox.hasName()) {
             KMIME_WARN << "display-name \"" << maybeMailbox.name()
-                       << "\" in Return-Path!"
-              #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
-                       << endl
-              #else
-                       << Qt::endl
-              #endif
-                          ;
+                       << "\" in Return-Path!" << Qt::endl;
         }
     }
     d->mailbox = maybeMailbox;
@@ -1193,12 +1169,7 @@ bool ReturnPath::parse(const char *&scursor, const char *const send,
     // and warn if it wasn't:
     if (scursor != send) {
         KMIME_WARN << "trailing garbage after angle-addr in Return-Path!"
-              #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
-                   << endl
-              #else
-                   << Qt::endl
-              #endif
-                      ;
+                   << Qt::endl;
     }
     return true;
 }
@@ -1536,7 +1507,7 @@ QByteArray Newsgroups::as7BitString(bool withHeaderType) const {
 }
 
 void Newsgroups::fromUnicodeString(const QString & s, const QByteArray & b) {
-    Q_UNUSED(b);
+    Q_UNUSED(b)
     Q_D(Newsgroups);
     from7BitString(s.toUtf8());
     d->encCS = cachedCharset("UTF-8");
@@ -1571,24 +1542,21 @@ bool Newsgroups::isCrossposted() const {
 bool Newsgroups::parse(const char *&scursor, const char *const send, bool isCRLF) {
     Q_D(Newsgroups);
     clear();
-    forever {
-    eatCFWS(scursor, send, isCRLF);
-        if (scursor != send && *scursor == ',')
-        {
-            ++scursor;
-        }
-        eatCFWS(scursor, send, isCRLF);
-        if (scursor == send)
-        {
-            return true;
-        }
-        const char *start = scursor;
-        while (scursor != send && !isspace(*scursor) && *scursor != ',')
-        {
-            ++scursor;
-        }
-        QByteArray group(start, scursor - start);
-        d->groups.append(group);
+    while (true) {
+      eatCFWS(scursor, send, isCRLF);
+      if (scursor != send && *scursor == ',') {
+        ++scursor;
+      }
+      eatCFWS(scursor, send, isCRLF);
+      if (scursor == send) {
+        return true;
+      }
+      const char *start = scursor;
+      while (scursor != send && !isspace(*scursor) && *scursor != ',') {
+        ++scursor;
+      }
+      QByteArray group(start, scursor - start);
+      d->groups.append(group);
     }
     return true;
 }
