@@ -4,10 +4,7 @@
 
 #include <QFile>
 #include <QByteArray>
-#include <QVector>
-//#include <QString>
-
-//#include <stdio.h>
+#include <QMap>
 #include <iostream>
 #include <cstdlib>
 #include <cassert>
@@ -122,7 +119,7 @@ int main(int argc, char *argv[])
     }
 
     assert(action == Token);
-    Q_UNUSED(action); // avoid warning in release mode
+    Q_UNUSED(action) // avoid warning in release mode
 
     int index;
     for (index = 0 ; index < tokenTypesLen ; ++index) {
@@ -347,7 +344,8 @@ int main(int argc, char *argv[])
              << "result.displayName:\n"
              << endl;
         int i = 0;
-        foreach (const auto &it, result.mailboxList) {
+        const auto mailboxList = result.mailboxList;
+        for (const auto &it : mailboxList) {
             cout << "result.mailboxList[" << i << "].displayName:\n"
                  << (it).name() << endl
                  << "result.mailboxList[" << i << "].addrSpec.localPart:\n"
